==> climatecontrol-0.1.10.tar.gz: climatecontrol-0.1.10/climatecontrol/logtools.py <==
#!/usr/bin/env python

"""
Logging utilities.
"""

import os
import logging
import logging.config as logging_config

from functools import wraps
from copy import deepcopy
import time
from typing import Optional, Any, Callable, Dict

formatter = logging.Formatter  # type: Any
formatter.converter = time.gmtime
logger = logging.getLogger(__name__)  # type: logging.Logger


def log_exception(logger: logging.Logger, message='An unexpected error occurred!', reraise=True) -> Callable:
    def log_exception_decorator(f):
        @wraps(f)
        def wrapper(*args, **kwargs):
            try:
                return f(*args, **kwargs)
            except Exception:
                logger.exception(message)
                if reraise:
                    raise
        return wrapper
    return log_exception_decorator


DEFAULT_LOG_SETTINGS = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'default': {
            'format': '%(asctime)s UTC [%(levelname)s] %(name)s: %(message)s'
        }
    },
    'handlers': {
        'console': {
            'class': 'logging.StreamHandler',
            'formatter': 'default',
            'level': 'DEBUG'
        }
    },
    'root': {
        'level': 'INFO',
        'handlers': ["console"]
    }
}


def setup_logging(settings_file: Optional[str] = None,
                  env_prefix: str = 'APP_SETTINGS',
                  settings_file_env_suffix: str = 'SETTINGS_FILE',
                  logging_section: str = 'LOGGING') -> None:
    """Configure logging

    args:
        settings_file: pass to `settings_parser.Settings`
        env_prefix: passed to `settings_parser.Settings`
        settings_file_env_suffix: passed to `settings_parser.Settings`
        logging_section: string indicating what section of the configuration should be used as logging settings.
    """

    from .settings_parser import Settings, update_nested

    using_custom = False

    def parse(data: Dict) -> Dict:
        """Parse logging configuration data"""
        default_settings = deepcopy(DEFAULT_LOG_SETTINGS)
        logging_settings = data.get(logging_section.lower(), {})
        nonlocal using_custom
        using_custom = bool(logging_settings)
        try:
            logging_filename = logging_settings['filename']
        except KeyError:
            logging_filename = None
        else:
            del logging_settings['filename']
        logging_settings = update_nested(default_settings, logging_settings)
        if logging_filename:
            logging_settings['handlers']['file']['filename'] = logging_filename
        return logging_settings

    logging_settings = Settings(settings_file=settings_file,
                                env_prefix=env_prefix,
                                settings_file_env_suffix=settings_file_env_suffix,
                                parser=parse)
    logging_config.dictConfig(logging_settings)

    if not using_custom:
        logger.warning('Custom log settings not found.  Using defaults.')

==> climatecontrol-0.2.3.tar.gz: climatecontrol-0.2.3/climatecontrol/logtools.py <==
#!/usr/bin/env python

"""
Logging utilities.
"""

import logging
import logging.config as logging_config

from copy import deepcopy
import time
from typing import Optional, Dict, Any  # noqa: F401

formatter = logging.Formatter  # type: Any
formatter.converter = time.gmtime
logger = logging.getLogger(__name__)  # type: logging.Logger


DEFAULT_LOG_SETTINGS = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'default': {
            'format': '%(asctime)s UTC [%(levelname)s] %(name)s: %(message)s'
        }
    },
    'handlers': {
        'console': {
            'class': 'logging.StreamHandler',
            'formatter': 'default',
            'level': 'DEBUG'
        }
    },
    'root': {
        'level': 'INFO',
        'handlers': ["console"]
    }
}


def setup_logging(settings_file: Optional[str] = None,
                  env_prefix: str = 'APP_SETTINGS',
                  settings_file_suffix: str = 'SETTINGS_FILE',
                  logging_section: str = 'LOGGING') -> None:
    """Configure logging

    args:
        settings_file: pass to `settings_parser.Settings`
        env_prefix: passed to `settings_parser.Settings`
        settings_file_suffix: passed to `settings_parser.Settings`
        logging_section: string indicating what section of the configuration should be used as logging settings.
    """

    from .settings_parser import Settings, update_nested

    using_custom = False

    def parse(data: Dict) -> Dict:
        """Parse logging configuration data"""
        default_settings = deepcopy(DEFAULT_LOG_SETTINGS)
        logging_settings = data.get(logging_section.lower(), {})
        nonlocal using_custom
        using_custom = bool(logging_settings)
        try:
            logging_filename = logging_settings['filename']
        except KeyError:
            logging_filename = None
        else:
            del logging_settings['filename']
        logging_settings = update_nested(default_settings, logging_settings)
        if logging_filename:
            logging_settings['handlers']['file']['filename'] = logging_filename
        return logging_settings

    logging_settings = Settings(settings_files=settings_file,
                                prefix=env_prefix,
                                settings_file_suffix=settings_file_suffix,
                                parser=parse)
    logging_config.dictConfig(logging_settings)

    if not using_custom:
        logger.warning('Custom log settings not found.  Using defaults.')
